var searchData=
[
  ['text_20conversion',['Text Conversion',['../group__group__class__conv.html',1,'']]],
  ['threading',['Threading',['../group__group__class__threading.html',1,'']]],
  ['threads',['Threads',['../group__group__funcmacro__thread.html',1,'']]],
  ['time',['Time',['../group__group__funcmacro__time.html',1,'']]],
  ['toolbar_20overview',['Toolbar Overview',['../overview_toolbar.html',1,'page_topics']]],
  ['the_20open_20group_20and_20dec_20license',['The Open Group and DEC License',['../page_copyright_xserver.html',1,'page_copyright']]],
  ['translations_20to_20other_20languages',['Translations to Other Languages',['../page_translations.html',1,'index']]],
  ['tab',['Tab',['../classwx_styled_text_ctrl.html#a2e1952f8b5c3dff0c1522465bc9ae109',1,'wxStyledTextCtrl']]],
  ['tab_5fleave',['Tab_Leave',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77ea44372b92451f5fbfbbc04cb9715d6845',1,'wxGrid']]],
  ['tab_5fstop',['Tab_Stop',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77eaba1f385a175029a3987f62277ebd3ade',1,'wxGrid']]],
  ['tab_5fwrap',['Tab_Wrap',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77ea52b3bd87557d9d5cb7e5abfdf010717f',1,'wxGrid']]],
  ['tabbehaviour',['TabBehaviour',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77e',1,'wxGrid']]],
  ['tabhittest',['TabHitTest',['../classwx_aui_tab_container.html#a4b30e80abdde9b3e4a83127ef9eb24d6',1,'wxAuiTabContainer']]],
  ['takedata',['TakeData',['../classwx_custom_data_object.html#a133a6a8044d298b68b50945c422ae4a8',1,'wxCustomDataObject']]],
  ['targetfromselection',['TargetFromSelection',['../classwx_styled_text_ctrl.html#ab943ccce1bf3a135bea42becef9d5653',1,'wxStyledTextCtrl']]],
  ['tarstrm_2eh',['tarstrm.h',['../tarstrm_8h.html',1,'']]],
  ['taskbar_2eh',['taskbar.h',['../taskbar_8h.html',1,'']]],
  ['taskbarbutton_2eh',['taskbarbutton.h',['../taskbarbutton_8h.html',1,'']]],
  ['tchar_5fstr',['tchar_str',['../classwx_string.html#aea75e9a0639470adcc2c8260156038e3',1,'wxString']]],
  ['tell',['Tell',['../classwx_f_file.html#a1b84187b39d443c83f37727a4e69051f',1,'wxFFile::Tell()'],['../classwx_temp_file.html#a7b930c371b6546950903949f6000dc13',1,'wxTempFile::Tell()'],['../classwx_file.html#afc7eaf653255bf2db25f20626d3eedb1',1,'wxFile::Tell()'],['../classwx_media_ctrl.html#aa859c2a3157cecc823f853540a9097a2',1,'wxMediaCtrl::Tell()'],['../classwx_stream_buffer.html#ae95ffab896829ec7d2e8b821f42c0ab5',1,'wxStreamBuffer::Tell()']]],
  ['telli',['TellI',['../classwx_input_stream.html#aece5e9ece88100f15fa91802b005ef4b',1,'wxInputStream']]],
  ['tello',['TellO',['../classwx_output_stream.html#acb127540592e6b5a3e8787329eb696a4',1,'wxOutputStream']]],
  ['testdestroy',['TestDestroy',['../classwx_thread.html#a9a3acec44b06b2a2430c5659991a3eac',1,'wxThread']]],
  ['text',['Text',['../classwx_busy_info_flags.html#aaf0327e70e6902b53c786f0ff93d679b',1,'wxBusyInfoFlags::Text()'],['../classwx_u_i_action_simulator.html#af8daaf3d87f184e2dec185b820eab9b3',1,'wxUIActionSimulator::Text()']]],
  ['textcompleter_2eh',['textcompleter.h',['../textcompleter_8h.html',1,'']]],
  ['textctrl_2eh',['textctrl.h',['../textctrl_8h.html',1,'']]],
  ['textdlg_2eh',['textdlg.h',['../textdlg_8h.html',1,'']]],
  ['textentry_2eh',['textentry.h',['../textentry_8h.html',1,'']]],
  ['textfile_2eh',['textfile.h',['../textfile_8h.html',1,'']]],
  ['textheight',['TextHeight',['../classwx_styled_text_ctrl.html#ae955348ccf4efd231357c6d96f299589',1,'wxStyledTextCtrl']]],
  ['textindent',['TextIndent',['../structwx_combo_ctrl_features.html#a58a86088b84a95c19601d3a89d7360b2ae2bdb81415edb3da2ad99e152a98ddfc',1,'wxComboCtrlFeatures']]],
  ['textwidth',['TextWidth',['../classwx_styled_text_ctrl.html#a52586525a7af5c901828ca8a44ae71ba',1,'wxStyledTextCtrl']]],
  ['textwrapper_2eh',['textwrapper.h',['../textwrapper_8h.html',1,'']]],
  ['tglbtn_2eh',['tglbtn.h',['../tglbtn_8h.html',1,'']]],
  ['thaw',['Thaw',['../classwx_window.html#a279a532124073261b28131b6afb59a1e',1,'wxWindow']]],
  ['this',['This',['../classwx_thread.html#a7077fa46ffef0fd1d023628776598335',1,'wxThread']]],
  ['thread_2eh',['thread.h',['../docs_2doxygen_2overviews_2thread_8h.html',1,'']]],
  ['thread_2eh',['thread.h',['../interface_2wx_2thread_8h.html',1,'']]],
  ['threadid',['threadId',['../classwx_log_record_info.html#af7766219720d7215dcdef349d247916e',1,'wxLogRecordInfo']]],
  ['thu',['Thu',['../classwx_date_time.html#a9ce844e5c79b28711f52ae2d9a571457aefdce3348770a8e30443bd559cd272e9',1,'wxDateTime']]],
  ['tile',['Tile',['../classwx_m_d_i_parent_frame.html#a7f1eff1bf46b4f7a399d1d20ca3ed374',1,'wxMDIParentFrame']]],
  ['time',['Time',['../classwx_stop_watch.html#aa80ff19ed90b2b99c879ec9ea3e7a71d',1,'wxStopWatch']]],
  ['time_2eh',['time.h',['../time_8h.html',1,'']]],
  ['timectrl_2eh',['timectrl.h',['../timectrl_8h.html',1,'']]],
  ['timeinmicro',['TimeInMicro',['../classwx_stop_watch.html#ab80191c8153ce08823c31b116feea122',1,'wxStopWatch']]],
  ['timeout_5fauto',['Timeout_Auto',['../classwx_notification_message.html#ad68c605c95d9cb9824e01a4326c8a176a5b4a8e2f2e6ed0a8fe76016be6ee7942',1,'wxNotificationMessage']]],
  ['timeout_5fnever',['Timeout_Never',['../classwx_notification_message.html#ad68c605c95d9cb9824e01a4326c8a176a56e3ea77b58c4b79887804eddfdabe78',1,'wxNotificationMessage']]],
  ['timer_2eh',['timer.h',['../timer_8h.html',1,'']]],
  ['timestamp',['timestamp',['../classwx_log_record_info.html#a702d51504b8ae8b313f642de68f38964',1,'wxLogRecordInfo']]],
  ['timezone',['TimeZone',['../classwx_date_time_1_1_time_zone.html#a6c92018c57951577204d0cc844187f6b',1,'wxDateTime::TimeZone::TimeZone(TZ tz)'],['../classwx_date_time_1_1_time_zone.html#a62f55033025c400f4337df35a1421f6a',1,'wxDateTime::TimeZone::TimeZone(long offset=0)']]],
  ['timezone',['TimeZone',['../classwx_date_time_1_1_time_zone.html',1,'wxDateTime']]],
  ['tipdlg_2eh',['tipdlg.h',['../tipdlg_8h.html',1,'']]],
  ['tips_2eh',['tips.h',['../tips_8h.html',1,'']]],
  ['tipwin_2eh',['tipwin.h',['../tipwin_8h.html',1,'']]],
  ['title',['Title',['../classwx_busy_info_flags.html#aa514f1204a0a3f43c6529360d495de22',1,'wxBusyInfoFlags']]],
  ['tls_2eh',['tls.h',['../tls_8h.html',1,'']]],
  ['tm',['Tm',['../structwx_date_time_1_1_tm.html',1,'wxDateTime']]],
  ['to8bitdata',['To8BitData',['../classwx_string.html#afa91a632574bcbba1bf35b54f2c5562a',1,'wxString']]],
  ['toascii',['ToAscii',['../classwx_string.html#a51d79ada5701a552d698c8fa9ffe208b',1,'wxString::ToAscii(char replaceWith= &apos;_&apos;) const '],['../classwx_string.html#acd171199184fea05c454ebfd309d6e68',1,'wxString::ToAscii(char replaceWith= &apos;_&apos;) const ']]],
  ['tocdouble',['ToCDouble',['../classwx_string.html#a81ee01c0c1f9c2264506d674f1f2b733',1,'wxString']]],
  ['toclong',['ToCLong',['../classwx_string.html#a2d7fb808fae67a4226ebeedf854a5a03',1,'wxString']]],
  ['toculong',['ToCULong',['../classwx_string.html#a545b481942916202dacaaee5e558d035',1,'wxString']]],
  ['today',['Today',['../classwx_date_time.html#af730202238b9acd5a5df2977fa40c569',1,'wxDateTime']]],
  ['todip',['ToDIP',['../classwx_window.html#ae9b6cfa33d3250fea284d6257e09d123',1,'wxWindow::ToDIP(const wxSize &amp;sz) const '],['../classwx_window.html#a94cdc7e439ec0700e678656a003b4e8c',1,'wxWindow::ToDIP(const wxPoint &amp;pt) const '],['../classwx_window.html#af30ae727bcf8b445a580979d738d421e',1,'wxWindow::ToDIP(int d) const '],['../classwx_window.html#a664dc49139d0f91fc3717994b0a5b4e6',1,'wxWindow::ToDIP(const wxSize &amp;sz, const wxWindow *w)'],['../classwx_window.html#aef413f1d0252a7a5a29512e8ab5e7c91',1,'wxWindow::ToDIP(const wxPoint &amp;pt, const wxWindow *w)'],['../classwx_window.html#a664dc49139d0f91fc3717994b0a5b4e6',1,'wxWindow::ToDIP(const wxSize &amp;sz, const wxWindow *w)']]],
  ['todo_20list',['Todo List',['../todo.html',1,'']]],
  ['todouble',['ToDouble',['../classwx_long_long.html#a5d0d84321018245413ac71939f3d80d2',1,'wxLongLong::ToDouble()'],['../classwx_string.html#afca98ce954f669ec69696372e81d46ac',1,'wxString::ToDouble()']]],
  ['toggle',['Toggle',['../classwx_tree_ctrl.html#a618a620d9a434bacf91a51202ab807b1',1,'wxTreeCtrl::Toggle()'],['../classwx_v_list_box.html#ae530f18573bd96ea497d64b1b1b18905',1,'wxVListBox::Toggle()']]],
  ['togglebutton',['ToggleButton',['../classwx_ribbon_button_bar.html#a8d69e9a70bf38693cc349bbf76f0735a',1,'wxRibbonButtonBar']]],
  ['togglecaretsticky',['ToggleCaretSticky',['../classwx_styled_text_ctrl.html#adfc2b57b5e8d2f1fb512437344aab923',1,'wxStyledTextCtrl']]],
  ['toggleflag',['ToggleFlag',['../classwx_settable_header_column.html#a4734d269e6b4454aae75eb3641f4b023',1,'wxSettableHeaderColumn']]],
  ['togglefold',['ToggleFold',['../classwx_styled_text_ctrl.html#a41820dbb85f0b04756552982f276e621',1,'wxStyledTextCtrl']]],
  ['toggleitemselection',['ToggleItemSelection',['../classwx_tree_ctrl.html#a458eab144e16efbaf283748bacc475f7',1,'wxTreeCtrl']]],
  ['togglesortbycolumn',['ToggleSortByColumn',['../classwx_data_view_ctrl.html#a84b66d5faa59df90591417d3b4a520f8',1,'wxDataViewCtrl']]],
  ['togglesortorder',['ToggleSortOrder',['../classwx_settable_header_column.html#a85f9c3278526a0f60b79fd32607d31bb',1,'wxSettableHeaderColumn']]],
  ['toggletool',['ToggleTool',['../classwx_aui_tool_bar.html#af817c944bfe3e437e5fbac112aa9ac9c',1,'wxAuiToolBar::ToggleTool()'],['../classwx_ribbon_tool_bar.html#aaaf93abfe569a7c42a240d804e750131',1,'wxRibbonToolBar::ToggleTool()'],['../classwx_tool_bar.html#a9a7a9fb115b35f267d4b10a293667542',1,'wxToolBar::ToggleTool()']]],
  ['togglewindowstyle',['ToggleWindowStyle',['../classwx_window.html#a8a4fa47129de552bfec37db8c69688a2',1,'wxWindow']]],
  ['tointernal',['ToInternal',['../classwx_rich_text_range.html#a2376d2cda63d59bd5aadb76b5a7c28e7',1,'wxRichTextRange']]],
  ['tokenzr_2eh',['tokenzr.h',['../tokenzr_8h.html',1,'']]],
  ['tolong',['ToLong',['../classwx_long_long.html#a1f3e078524d8d495bbc130c93b6fbdf2',1,'wxLongLong::ToLong()'],['../classwx_string.html#abb54083175bbc1e1164616b4aa64fcd8',1,'wxString::ToLong()']]],
  ['tolonglong',['ToLongLong',['../classwx_string.html#a978e566d90ff4ed900fb353c7160c4d2',1,'wxString']]],
  ['toolbar_2eh',['toolbar.h',['../docs_2doxygen_2overviews_2toolbar_8h.html',1,'']]],
  ['toolbar_2eh',['toolbar.h',['../interface_2wx_2ribbon_2toolbar_8h.html',1,'']]],
  ['toolbar_2eh',['toolbar.h',['../interface_2wx_2toolbar_8h.html',1,'']]],
  ['toolbarpane',['ToolbarPane',['../classwx_aui_pane_info.html#a6ef47a9e70b74a1b9b0260f009ecf3c5',1,'wxAuiPaneInfo']]],
  ['toolbook_2eh',['toolbook.h',['../toolbook_8h.html',1,'']]],
  ['tooltip_2eh',['tooltip.h',['../tooltip_8h.html',1,'']]],
  ['top',['Top',['../classwx_aui_pane_info.html#a2b6d3cdd44942939cf0cb456307d4e4f',1,'wxAuiPaneInfo::Top()'],['../classwx_sizer_flags.html#a332570b2ce022f6ad56206eda0b866ae',1,'wxSizerFlags::Top()'],['../classwx_layout_constraints.html#a129cfa4472889328c561b3c7dfa6494b',1,'wxLayoutConstraints::top()'],['../classwx_stack_3_01_t_01_4.html#a88468b033c07c9e1e6db68f10d405d37',1,'wxStack&lt; T &gt;::top()'],['../classwx_stack_3_01_t_01_4.html#a7f05c401d1a331de4ce3a50c65d01404',1,'wxStack&lt; T &gt;::top()']]],
  ['topdockable',['TopDockable',['../classwx_aui_pane_info.html#a1485700166fccf0d5e26795e836a35f9',1,'wxAuiPaneInfo']]],
  ['topics_2eh',['topics.h',['../topics_8h.html',1,'']]],
  ['toplevel_2eh',['toplevel.h',['../persist_2toplevel_8h.html',1,'']]],
  ['toplevel_2eh',['toplevel.h',['../toplevel_8h.html',1,'']]],
  ['torawstring',['ToRawString',['../classwx_accelerator_entry.html#ae1da1f2622d05fc436b552de71b14d96',1,'wxAcceleratorEntry']]],
  ['tostdstring',['ToStdString',['../classwx_string.html#a3c764622c960389c4d8c9e21e13bddc7',1,'wxString']]],
  ['tostdwstring',['ToStdWstring',['../classwx_string.html#acd4ba44e34428aa83cd9922d2933d060',1,'wxString']]],
  ['tostring',['ToString',['../classwx_accelerator_entry.html#a0d164fa98bba518e6b6f9cca65332d36',1,'wxAcceleratorEntry::ToString()'],['../classwx_colour_data.html#a3852e5257218136d8d04b866adadbd41',1,'wxColourData::ToString()'],['../classwx_native_font_info.html#af500d02d485369dca5ca63679885153d',1,'wxNativeFontInfo::ToString()'],['../classwx_file_system_watcher_event.html#aa45e2d5f40f2c19a4c758f0dcaf44631',1,'wxFileSystemWatcherEvent::ToString()'],['../classwx_long_long.html#ab53c850616c14e473d614110f7d5e7ee',1,'wxLongLong::ToString()'],['../classwx_number_formatter.html#abf3e465bc68a79821b00387271386fd3',1,'wxNumberFormatter::ToString(long val, int flags=Style_WithThousandsSep)'],['../classwx_number_formatter.html#a42c2c2129c5bf3693e6a3699bae8595f',1,'wxNumberFormatter::ToString(double val, int precision, int flags=Style_WithThousandsSep)'],['../classwx_version_info.html#a4954ed97dcb394535948dd4d85e4186d',1,'wxVersionInfo::ToString()']]],
  ['totext',['ToText',['../classwx_html_window.html#aacc7ffe8844ca638008fff488b05314c',1,'wxHtmlWindow']]],
  ['totimezone',['ToTimezone',['../classwx_date_time.html#a254dff0f6fb8861216941dcc3d4fdc15',1,'wxDateTime']]],
  ['touch',['Touch',['../classwx_file_name.html#a4471ce6c004e35014da63d480349e7a9',1,'wxFileName']]],
  ['toulong',['ToULong',['../classwx_string.html#a36a50d60b6d2ff7a08f112c8db8fc109',1,'wxString']]],
  ['toulonglong',['ToULongLong',['../classwx_string.html#ab9a3972bffb4edf0b5568b23f519de01',1,'wxString']]],
  ['touserstring',['ToUserString',['../classwx_native_font_info.html#a9f1113b6ebac635b6e1a767f8b8f5261',1,'wxNativeFontInfo']]],
  ['toutc',['ToUTC',['../classwx_date_time.html#a4bddd303b09cc47c7251b01ca49dc04c',1,'wxDateTime']]],
  ['toutf8',['ToUTF8',['../classwx_string.html#ac923e0bcfda57ec5064dcade9808db94',1,'wxString']]],
  ['towchar',['ToWChar',['../classwx_m_b_conv.html#a22ad1976c06a540a95dfa878038d65f2',1,'wxMBConv']]],
  ['tracker_2eh',['tracker.h',['../tracker_8h.html',1,'']]],
  ['transferdatafromwindow',['TransferDataFromWindow',['../classwx_window.html#ab8e51f36e7d8790b361c8d8c6f37b1ad',1,'wxWindow']]],
  ['transferdatatowindow',['TransferDataToWindow',['../classwx_window.html#a88cc65e424a129d9b0057756cdb67ec9',1,'wxWindow']]],
  ['transferfromwindow',['TransferFromWindow',['../classwx_generic_validator.html#acf9a45aa5199fda6e95db482aa238c92',1,'wxGenericValidator::TransferFromWindow()'],['../classwx_validator.html#acffa9472b2f741ab29dbfad3b80934da',1,'wxValidator::TransferFromWindow()'],['../classwx_num_validator.html#a583b267471b029df2b8d0e49f45d9141',1,'wxNumValidator::TransferFromWindow()'],['../classwx_text_validator.html#a2fcf41e1c0fb40177703f96b3e60193f',1,'wxTextValidator::TransferFromWindow()']]],
  ['transfermode',['TransferMode',['../classwx_f_t_p.html#aaeeaee850fd01f6063ba62fab8e89d51',1,'wxFTP']]],
  ['transfertowindow',['TransferToWindow',['../classwx_generic_validator.html#aae15ba89856f2e15fc05c8b073f27660',1,'wxGenericValidator::TransferToWindow()'],['../classwx_validator.html#aa09f9ae3bace5de7a8e577206b75aeae',1,'wxValidator::TransferToWindow()'],['../classwx_num_validator.html#a629f0860d54bf200fe8779e7daa9a863',1,'wxNumValidator::TransferToWindow()'],['../classwx_text_validator.html#acc486deab1ed74c3f8799e56b8056cbe',1,'wxTextValidator::TransferToWindow()']]],
  ['transform',['Transform',['../classwx_transform2_d.html#a40161861f1c3e167fb65ba364695690d',1,'wxTransform2D::Transform(wxPoint2DInt *pt) const =0'],['../classwx_transform2_d.html#aa5fa07dc79762b996f27a5937b758b6e',1,'wxTransform2D::Transform(wxRect2DInt *r) const '],['../classwx_transform2_d.html#af2b729a50fe8611f49406f1666632bc4',1,'wxTransform2D::Transform(const wxPoint2DInt &amp;pt) const '],['../classwx_transform2_d.html#a8fed5ee4fe6f39a7ad8a32402ae62af2',1,'wxTransform2D::Transform(const wxRect2DInt &amp;r) const '],['../classwx_graphics_path.html#a6a6a766853d1e57678c2d54e2eea490d',1,'wxGraphicsPath::Transform()']]],
  ['transformdistance',['TransformDistance',['../classwx_affine_matrix2_d.html#a47def85a019c68e7b672c34b3e2b8427',1,'wxAffineMatrix2D::TransformDistance(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d.html#ab024db742b913618e7138b846656c385',1,'wxAffineMatrix2D::TransformDistance(wxDouble *dx, wxDouble *dy) const '],['../classwx_affine_matrix2_d_base.html#a6503debd3b857e360d53a375bc7e8429',1,'wxAffineMatrix2DBase::TransformDistance(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d_base.html#a1bd444b69b9f13469793924b66df3bd4',1,'wxAffineMatrix2DBase::TransformDistance(wxDouble *dx, wxDouble *dy) const '],['../classwx_graphics_matrix.html#a7c260921b498791c1355d3ae2fe4a3e0',1,'wxGraphicsMatrix::TransformDistance()']]],
  ['transformpoint',['TransformPoint',['../classwx_affine_matrix2_d.html#aad371443939e426e693a05befe2e3cd3',1,'wxAffineMatrix2D::TransformPoint(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d.html#ac2fe105565117945524e1305152647e1',1,'wxAffineMatrix2D::TransformPoint(wxDouble *x, wxDouble *y) const '],['../classwx_affine_matrix2_d_base.html#a00b4abff8fe77431fc4ed2a9523660c9',1,'wxAffineMatrix2DBase::TransformPoint(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d_base.html#ace16a72f1378d410936002f40c0a4841',1,'wxAffineMatrix2DBase::TransformPoint(wxDouble *x, wxDouble *y) const '],['../classwx_graphics_matrix.html#a27f4264be5407a9a584297c822b8deae',1,'wxGraphicsMatrix::TransformPoint()']]],
  ['translate',['Translate',['../classwx_affine_matrix2_d.html#a08f03e2a7b5ce37e6dc60d91ba2c43ab',1,'wxAffineMatrix2D::Translate()'],['../classwx_affine_matrix2_d_base.html#a5a2ab636aeff6db99cb3b534b0d9ea3a',1,'wxAffineMatrix2DBase::Translate()'],['../classwx_graphics_context.html#a3fcc8a79248f192c637ff89466939916',1,'wxGraphicsContext::Translate()'],['../classwx_graphics_matrix.html#ae91dc96cb34b4562179efb6c9857dc75',1,'wxGraphicsMatrix::Translate()']]],
  ['translation_2eh',['translation.h',['../translation_8h.html',1,'']]],
  ['translations_2eh',['translations.h',['../translations_8h.html',1,'']]],
  ['transparency',['Transparency',['../classwx_busy_info_flags.html#a6fddc2b30145b6f989e5b9e69dfdc557',1,'wxBusyInfoFlags']]],
  ['traverse',['Traverse',['../classwx_dir.html#a7621f55a0dff2a394e6da1a61e427df1',1,'wxDir']]],
  ['treebase_2eh',['treebase.h',['../treebase_8h.html',1,'']]],
  ['treebook_2eh',['treebook.h',['../treebook_8h.html',1,'']]],
  ['treebook_2eh',['treebook.h',['../persist_2treebook_8h.html',1,'']]],
  ['treectrl_2eh',['treectrl.h',['../interface_2wx_2treectrl_8h.html',1,'']]],
  ['treectrl_2eh',['treectrl.h',['../docs_2doxygen_2overviews_2treectrl_8h.html',1,'']]],
  ['treelist_2eh',['treelist.h',['../treelist_8h.html',1,'']]],
  ['trim',['Trim',['../classwx_string.html#aefd36feb8f3c36edcf3322f84de0bfc4',1,'wxString']]],
  ['tripleborder',['TripleBorder',['../classwx_sizer_flags.html#a799590935571940a5a7c28c75a324243',1,'wxSizerFlags']]],
  ['truncate',['Truncate',['../classwx_stream_buffer.html#a10875bdb145f030ee082ab26cab2c694',1,'wxStreamBuffer::Truncate()'],['../classwx_string.html#a9b66809526638b11208bfe36cf895f36',1,'wxString::Truncate()']]],
  ['tryafter',['TryAfter',['../classwx_evt_handler.html#a5e25fece1cb6cbc11fd1d41ec140319c',1,'wxEvtHandler']]],
  ['trybefore',['TryBefore',['../classwx_evt_handler.html#ad4b0eac704dd005ac6a88fdb1e673c13',1,'wxEvtHandler']]],
  ['tryenter',['TryEnter',['../classwx_critical_section.html#abb732e66f2b0e6f38d30f29a25d8851a',1,'wxCriticalSection']]],
  ['trylock',['TryLock',['../classwx_mutex.html#a4485a8234390d1adc69426337069602b',1,'wxMutex']]],
  ['trywait',['TryWait',['../classwx_semaphore.html#a578840a5c04cea87b0121c8e43d480a2',1,'wxSemaphore']]],
  ['tue',['Tue',['../classwx_date_time.html#a9ce844e5c79b28711f52ae2d9a571457ae1277871c9d23518b6137b9d9b005138',1,'wxDateTime']]],
  ['txtstrm_2eh',['txtstrm.h',['../txtstrm_8h.html',1,'']]],
  ['type',['type',['../structwx_cmd_line_entry_desc.html#ab37bbf61b24d4cbea96f42cac315f0ea',1,'wxCmdLineEntryDesc']]],
  ['type_5fbinary',['Type_Binary',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea74fb86bd34628fe6c23cfaa7b547b79a',1,'wxRegKey']]],
  ['type_5fboolean',['Type_Boolean',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4a5338e90a8c51020109928f3177c06caf',1,'wxConfigBase']]],
  ['type_5fdword',['Type_Dword',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeacb0782c3f7b99336f78371753970cf6f',1,'wxRegKey']]],
  ['type_5fdword_5fbig_5fendian',['Type_Dword_big_endian',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeae27492abe54a132c0899fc2110758207',1,'wxRegKey']]],
  ['type_5fdword_5flittle_5fendian',['Type_Dword_little_endian',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeab87e643f6dbb322dc67364f2d25e8d51',1,'wxRegKey']]],
  ['type_5fexpand_5fstring',['Type_Expand_String',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeacc5cd22316a3273670261ed85bf9d72e',1,'wxRegKey']]],
  ['type_5ffloat',['Type_Float',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4af1cafe0a03c8c929511258c31ea138cb',1,'wxConfigBase']]],
  ['type_5ffull_5fresource_5fdescriptor',['Type_Full_resource_descriptor',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeab2319e2d3f1021f2bb44b2c7cb9ed505',1,'wxRegKey']]],
  ['type_5finteger',['Type_Integer',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4abf7985582695bbed6da7d2de5b22b6e8',1,'wxConfigBase']]],
  ['type_5flink',['Type_Link',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeacc7e8383cc247869748a32caa8955f6c',1,'wxRegKey']]],
  ['type_5fmulti_5fstring',['Type_Multi_String',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea5c2c7552289566cf5fa2f23b9c619cff',1,'wxRegKey']]],
  ['type_5fnone',['Type_None',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea49efeb70b7042259a6aef6086131dafb',1,'wxRegKey']]],
  ['type_5fresource_5flist',['Type_Resource_list',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea89ec527597463d6dddeaff9297a2ea0e',1,'wxRegKey']]],
  ['type_5fresource_5frequirements_5flist',['Type_Resource_requirements_list',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea47a10b01b23342d005164295bb4a8935',1,'wxRegKey']]],
  ['type_5fstring',['Type_String',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4afeb4cd8ae582520fd2d45ec35b316d0a',1,'wxConfigBase::Type_String()'],['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea71e34e7ea0dd2326613f48db8d086c16',1,'wxRegKey::Type_String()']]],
  ['type_5funknown',['Type_Unknown',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4a186e69ade61db5ba7e5fc2366d2388fc',1,'wxConfigBase']]],
  ['typedefault',['typeDefault',['../classwx_text_file.html#a2556d86c0c6130379d9122a3c076340b',1,'wxTextFile']]],
  ['tz',['TZ',['../classwx_date_time.html#a4db12283a6c06cea4c92528fbb7f88bb',1,'wxDateTime']]]
];
